{% extends "horizon/common/_modal_form.html" %}
{% load i18n %}
{% load url from future %}

{% block form_id %}add_routerrule_form{% endblock %}
{% block form_action %}{% url 'horizon:project:connections:routerrules:addrouterrule' %}
{% endblock %}

{% block modal-header %}{% trans "Add Router Policy" %}{% endblock %}

{% block modal-body %}
<div class="left">
    <fieldset>
        {% include "horizon/common/_form_fields.html" %}
    </fieldset>
</div>
<div class="right">
    <h3>{% trans "Description:" %}</h3>
    <p>
    {% trans "Routing policies to apply to router. Policies are matched by most specific source first and then by most specific destination." %}<br/>
    {% trans "The next hop addresses can be used to override the router used by the client." %}<br/>
    {% trans "Next hop addresses are ignored for Deny action policies." %}
    </p>
</div>
{% endblock %}

{% block modal-footer %}
  <input class="btn btn-primary pull-right" type="submit" value="{% trans "Add Policy" %}" />
  <a href="{% url 'horizon:project:connections:index' %}" class="btn btn-default secondary cancel close">{% trans "Cancel" %}</a>
{% endblock %}
